@@ -12,7 +12,7 @@ use MooX::Types::MooseLike::Base qw(HashRef Str);
 use Set::Scalar;
 use namespace::autoclean;
 
-our $VERSION = '2.013';
+our $VERSION = '2.014';
 
 has category => (
     is      => 'rw',
@@ -226,7 +226,10 @@ sub merge_extract {
                     grep { defined && length }
                     ref $any eq 'ARRAY' ? @{$any} : $any;
                 return @parts
-                    ? ( join ' | ', @parts )
+                    ? do {
+                        my $joined = join ' | ', @parts;
+                        qr{ $joined }xms;
+                    }
                     : qr{ (?!) }xms;
             };
             my $regex     = $to_regex->( $skip_new_messages->{no_skip_for} );
@@ -288,7 +291,7 @@ $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/extract/trun
 
 =head1 VERSION
 
-2.013
+2.014
 
 =head1 DESCRIPTION
 
